aboutsummaryrefslogtreecommitdiff
path: root/include/wlr
diff options
context:
space:
mode:
Diffstat (limited to 'include/wlr')
-rw-r--r--include/wlr/types/wlr_export_dmabuf_v1.h2
-rw-r--r--include/wlr/types/wlr_output.h9
-rw-r--r--include/wlr/types/wlr_screencopy_v1.h2
3 files changed, 6 insertions, 7 deletions
diff --git a/include/wlr/types/wlr_export_dmabuf_v1.h b/include/wlr/types/wlr_export_dmabuf_v1.h
index 204da985..42c88e5c 100644
--- a/include/wlr/types/wlr_export_dmabuf_v1.h
+++ b/include/wlr/types/wlr_export_dmabuf_v1.h
@@ -35,7 +35,7 @@ struct wlr_export_dmabuf_frame_v1 {
bool cursor_locked;
- struct wl_listener output_swap_buffers;
+ struct wl_listener output_precommit;
};
struct wlr_export_dmabuf_manager_v1 *wlr_export_dmabuf_manager_v1_create(
diff --git a/include/wlr/types/wlr_screencopy_v1.h b/include/wlr/types/wlr_screencopy_v1.h
index c7197bab..ff76d829 100644
--- a/include/wlr/types/wlr_screencopy_v1.h
+++ b/include/wlr/types/wlr_screencopy_v1.h
@@ -42,7 +42,7 @@ struct wlr_screencopy_frame_v1 {
struct wl_listener buffer_destroy;
struct wlr_output *output;
- struct wl_listener output_swap_buffers;
+ struct wl_listener output_precommit;
void *data;
};
diff --git a/include/wlr/types/wlr_output.h b/include/wlr/types/wlr_output.h
index b2f4cff9..e50f9ba3 100644
--- a/include/wlr/types/wlr_output.h
+++ b/include/wlr/types/wlr_output.h
@@ -56,7 +56,7 @@ enum wlr_output_state_field {
*/
struct wlr_output_state {
uint32_t committed; // enum wlr_output_state_field
- pixman_region32_t damage;
+ pixman_region32_t damage; // output-buffer-local coordinates
};
struct wlr_output_impl;
@@ -111,8 +111,8 @@ struct wlr_output {
// Emitted when buffers need to be swapped (because software cursors or
// fullscreen damage or because of backend-specific logic)
struct wl_signal needs_commit;
- // Emitted right before buffer swap
- struct wl_signal swap_buffers; // wlr_output_event_swap_buffers
+ // Emitted right before buffer commit
+ struct wl_signal precommit; // wlr_output_event_precommit
// Emitted right after the buffer has been presented to the user
struct wl_signal present; // wlr_output_event_present
struct wl_signal enable;
@@ -133,10 +133,9 @@ struct wlr_output {
void *data;
};
-struct wlr_output_event_swap_buffers {
+struct wlr_output_event_precommit {
struct wlr_output *output;
struct timespec *when;
- pixman_region32_t *damage; // output-buffer-local coordinates
};
enum wlr_output_present_flag {